svapls-package: Surrogate variable analysis using Partial Least Squares in a gene expression
data
Description
The package svapls contains functions that are intended for the
identification, correction and visualization of the hidden variability owing
to a variety of unknown subject/sample specific effects of residual heterogeneity
in a gene expression data.
Arguments
Details
ll{
Package: svapls
Type: Package
Version: 1.0
Date: 2012-07-23
License: GPL-3
}
The package can be used to find the genes that are truly differentially expressed
between two types of samples (tissue types, biological conditions like Cancer/Non-
Cancer samples, etc.), after adjusting for the hidden factors of residual
heterogeneity in the data. The function svpls detects the truly positive genes
after correcting for the hidden variation and also provides a modified gene
expression matrix which is free from the spurious effects of the residual
expression heterogeneity. Another important function hfp produces a heat-
map representing the intensity of latent variability due to the unknown sample-
specific factors, for any specified set of genes and subjects.
fitModel, svpls and hfp
References
Sutirtha Chakraborty, Somnath Datta and Susmita Datta. (2012)
Surrogate Variable Analysis Using Partial Least Squares in Gene
Expression Studies. Bioinformatics.